#include <stdio.h>
#include <string.h>
#include <inttypes.h>

#include "i2cmaster.h"
#include "eeprom.h"

#define ADDRESS_8_BIT	0
#define ADDRESS_16_BIT	1


uint8_t eeprom_read_block(uint8_t i2c_addr, uint8_t *buf, uint16_t offset, int length, uint8_t address_format)
{
	int addr;
	uint8_t val;
	uint8_t timeout_counter = 50;

	/* Acknowladge Polling See Datasheet */
	while(i2c_start((i2c_addr<<1)|I2C_WRITE)==1) {
		i2c_stop();
		if (timeout_counter-- == 0) return -1;
	}
	if (address_format == ADDRESS_16_BIT) {
		i2c_write((uint8_t)(offset >> 8));
	}
	i2c_write(offset);
	i2c_start((i2c_addr<<1) | I2C_READ);
	for (addr=0;addr<(length-1);addr++)	{
		val=i2c_readAck();
		buf[addr]=val;
	}
	val=i2c_readNak();
	buf[addr]=val;
	i2c_stop();
	return 0;
}



int eeprom_write_pagewise(uint8_t i2c_addr, uint8_t *buf, uint16_t length, uint8_t page_length, uint16_t offset, uint8_t address_format) {
	int addr;
	uint8_t timeout_counter;
	for (addr=0; addr < length; addr++) {
		timeout_counter = 50;
		if (addr%page_length==0) {
		i2c_stop();
		while(i2c_start((i2c_addr<<1)|I2C_WRITE)==1) {
        	i2c_stop(); // Acknowladge Polling See Datasheet
			if (timeout_counter-- == 0) return -1;
		}
        if (address_format == ADDRESS_16_BIT) {
			i2c_write((uint8_t)((addr+offset) >> 8));
		}
		i2c_write((uint8_t)(addr+offset));
      }
      i2c_write(buf[addr]);
    }
    i2c_stop();
    return 0;
}
