/* 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Taken from avrdude: Thanks for that great piece of software.
 */

#include <stdio.h>
#include <inttypes.h>
#include <string.h>
#include <ctype.h>


static int hexdump_line(char * buffer, unsigned char * p, int n, int pad);

static int chardump_line(char * buffer, unsigned char * p, int n, int pad);


/* Taken From AVRDUDE Source to Show Hexdump Table */
static int hexdump_line(char * buffer, unsigned char * p, int n, int pad) {
	char * hexdata = "0123456789ABCDEF";
	char * b;
	int i, j;

	b = buffer;

	j = 0;

	for (i=0; i<n; i++) {
	if (i && ((i % 8) == 0))
		b[j++] = ' ';

	b[j++] = hexdata[(p[i] & 0xf0) >> 4];
	b[j++] = hexdata[(p[i] & 0x0f)];

	if (i < 15)
		b[j++] = ' ';
	}

	for (i=j; i<pad; i++)
		b[i] = ' ';

	b[i] = 0;

	for (i=0; i<pad; i++) {
		if (!((b[i] == '0') || (b[i] == ' ')))
			return 0;
	}

	return 1;
}



/* Taken From AVRDUDE Source to Show Hexdump Table */
static int chardump_line(char * buffer, unsigned char * p, int n, int pad) {
	int i;
	char b [ 128 ];

	for (i=0; i<n; i++) {
		memcpy(b, p, n);
		buffer[i] = '.';

		if (isalpha(b[i]) || isdigit(b[i]) || ispunct(b[i]))
			buffer[i] = b[i];
		else if (isspace(b[i]))
			buffer[i] = ' ';
	}

	for (i=n; i<pad; i++)
		buffer[i] = ' ';

	buffer[i] = 0;

	return 0;
}



/* Taken From AVRDUDE Source to Show Hexdump Table */
int hexdump_buf(int startaddr, unsigned char * buf, int len) {
	int addr;
	int i, n;
	unsigned char * p;
	char dst1[80];
	char dst2[80];

	printf("Hexdump:\n");

	addr = startaddr;
	i = 0;
	p = (unsigned char *)buf;

	while (len) {
		n = 16;
		if (n > len)
			n = len;
		hexdump_line(dst1, p, n, 48);
		chardump_line(dst2, p, n, 16);
		fprintf(stdout, "%04X  %s       |%s|\n", addr, dst1, dst2);
		len -= n;
		addr += n;
		p += n;
	}

	return 0;
}
